@@ -79,7 +79,7 @@ impl Subcommand {
         justfile.run(config, &search, overrides, &[])?;
       }
       Dump => Self::dump(config, ast, justfile)?,
-      Format => Self::format(config, &search, src, ast)?,
+      Format => Self::format(config, &search, src, ast, justfile)?,
       Groups => Self::groups(config, justfile),
       List { path } => Self::list(config, justfile, path)?,
       Show { path } => Self::show(config, justfile, path)?,
@@ -110,9 +110,10 @@ impl Subcommand {
     ) {
       let starting_path = match &config.search_config {
         SearchConfig::FromInvocationDirectory => config.invocation_directory.clone(),
-        SearchConfig::FromSearchDirectory { search_directory } => {
-          env::current_dir().unwrap().join(search_directory)
-        }
+        SearchConfig::FromSearchDirectory { search_directory } => config
+          .invocation_directory
+          .join(search_directory)
+          .lexiclean(),
         _ => unreachable!(),
       };
 
@@ -189,7 +190,9 @@ impl Subcommand {
     loader: &'src Loader,
     search: &Search,
   ) -> RunResult<'src, Compilation<'src>> {
-    let compilation = Compiler::compile(config.unstable, loader, &search.justfile)?;
+    let compilation = Compiler::compile(loader, &search.justfile)?;
+
+    compilation.justfile.check_unstable(config)?;
 
     if config.verbosity.loud() {
       for warning in &compilation.justfile.warnings {
@@ -334,8 +337,14 @@ impl Subcommand {
     Ok(())
   }
 
-  fn format(config: &Config, search: &Search, src: &str, ast: &Ast) -> RunResult<'static> {
-    config.require_unstable("The `--fmt` command is currently unstable.")?;
+  fn format(
+    config: &Config,
+    search: &Search,
+    src: &str,
+    ast: &Ast,
+    justfile: &Justfile,
+  ) -> RunResult<'static> {
+    config.require_unstable(justfile, UnstableFeature::FormatSubcommand)?;
 
     let formatted = ast.to_string();
 
@@ -536,13 +545,13 @@ impl Subcommand {
       ordered.insert(0, None);
     }
 
+    let no_groups = groups.contains_key(&None) && groups.len() == 1;
+
     for (i, group) in ordered.into_iter().enumerate() {
       if i > 0 {
         println!();
       }
 
-      let no_groups = groups.contains_key(&None) && groups.len() == 1;
-
       if !no_groups {
         print!("{list_prefix}");
         if let Some(group) = &group {
@@ -602,7 +611,11 @@ impl Subcommand {
         Self::list_module(config, submodule, depth + 1);
       }
     } else {
-      for submodule in module.modules(config) {
+      for (i, submodule) in module.modules(config).into_iter().enumerate() {
+        if !no_groups && !groups.is_empty() && i == 0 {
+          println!();
+        }
+
         print!("{list_prefix}{} ...", submodule.name());
         format_doc(
           config,
