@@ -3,7 +3,7 @@ use super::*;
 fn case(justfile: &str, value: Value) {
   Test::new()
     .justfile(justfile)
-    .args(["--dump", "--dump-format", "json", "--unstable"])
+    .args(["--dump", "--dump-format", "json"])
     .stdout(format!("{}\n", serde_json::to_string(&value).unwrap()))
     .run();
 }
@@ -56,7 +56,9 @@ fn alias() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "ignore_comments": false,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -98,6 +100,7 @@ fn assignment() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -153,6 +156,7 @@ fn body() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -220,6 +224,7 @@ fn dependencies() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -325,6 +330,7 @@ fn dependency_argument() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -392,6 +398,7 @@ fn duplicate_recipes() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -437,6 +444,7 @@ fn duplicate_variables() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -485,6 +493,7 @@ fn doc_comment() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -519,6 +528,7 @@ fn empty_justfile() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -674,6 +684,7 @@ fn parameters() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -762,6 +773,7 @@ fn priors() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -810,6 +822,7 @@ fn private() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -858,6 +871,7 @@ fn quiet() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -921,6 +935,7 @@ fn settings() {
           "command": "a",
         },
         "tempdir": null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -972,6 +987,7 @@ fn shebang() {
         "quiet": false,
         "shell": null,
         "tempdir": null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -1020,6 +1036,7 @@ fn simple() {
         "quiet": false,
         "shell": null,
         "tempdir": null,
+        "unstable": false,
         "windows_powershell": false,
         "windows_shell": null,
       },
@@ -1070,6 +1087,7 @@ fn attribute() {
         "quiet": false,
         "shell": null,
         "tempdir" : null,
+        "unstable": false,
         "ignore_comments": false,
         "windows_powershell": false,
         "windows_shell": null,
@@ -1092,8 +1110,7 @@ fn module() {
     .tree(tree! {
       "foo.just": "bar:",
     })
-    .args(["--dump", "--dump-format", "json", "--unstable"])
-    .test_round_trip(false)
+    .args(["--dump", "--dump-format", "json"])
     .stdout(format!(
       "{}\n",
       serde_json::to_string(&json!({
@@ -1136,6 +1153,7 @@ fn module() {
               "quiet": false,
               "shell": null,
               "tempdir" : null,
+              "unstable": false,
               "ignore_comments": false,
               "windows_powershell": false,
               "windows_shell": null,
@@ -1158,6 +1176,7 @@ fn module() {
           "quiet": false,
           "shell": null,
           "tempdir" : null,
+          "unstable": false,
           "ignore_comments": false,
           "windows_powershell": false,
           "windows_shell": null,
